export * from './hander';
import { AddGraph } from "@/api/systemDesigner";
import { GraphType } from '@/enum';

/**
 * 打印图片
 * @param imgUri 图片地址
 */
export const printHandle = (imgUri: string) => {
  const iframe = document.createElement("iframe");
  iframe.style.height = "0";
  iframe.style.visibility = "hidden";
  iframe.style.width = "0";
  const str = `<html>
            <style media='print'>
                 @page{size:A4 landscape};margin:0mm;padding:0}
            </style>
            <body>
                 <img src="${imgUri}"/>
            </body>
	</html>
	`;
  iframe.setAttribute("srcdoc", str);
  document.body.appendChild(iframe);
  iframe.addEventListener("load", () => {
    iframe?.contentWindow?.print();
  });
  iframe?.contentWindow?.addEventListener("afterprint", function () {
    iframe?.parentNode?.removeChild(iframe);
  });
};

/* uuid */
export function uuid() {
  return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, function (c) {
    var r = (Math.random() * 16) | 0,
      v = c === "x" ? r : (r & 0x3) | 0x8;
    return v.toString(16);
  });
}

/**
 * 创建新的图形
 */
export const createNew = async (type: string) => {
  const res = await AddGraph({ type });
  const id = res?.result?.graph?.id;
  if(!id) return false;
  const { origin, pathname } = window.location;
  const enterpriseCode = sessionStorage.getItem("enterpriseCode");
  if(type === GraphType.mindmap) {
    window.open(`${origin}${pathname}#/mindmap/${id}?enterpriseCode=${enterpriseCode}`);
  } else {
    window.open(`${origin}${pathname}#/flow/${id}?enterpriseCode=${enterpriseCode}`);
  }
  return id;
};